@@ -2,7 +2,7 @@ from enum import IntEnum
 
 
 class Order(IntEnum):
-    """ Destination for choice """
+    """ Order to choose """
 
     TO_RIGHT = -1
     TO_LEFT = 0
